@@ -42,8 +42,15 @@ import shutil
 import subprocess
 import sys
 import tempfile
+import warnings
 import xml.etree.ElementTree
 
+if sys.version_info < (3, 7):
+    warnings.warn(
+        "Python versions prior 3.7 are deprecated. Please update your python version.",
+        FutureWarning
+    )
+
 try:
     import configparser
 except ImportError:
@@ -73,7 +80,7 @@ if SPHINX_INSTALLED:
     import sphinx.roles
 
 
-__version__ = '3.4.0'
+__version__ = '3.5.0'
 
 
 if SPHINX_INSTALLED:
